You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@groovy.apache.org by pa...@apache.org on 2019/05/20 08:45:33 UTC

[groovy-website] branch asf-site updated (a76a617 -> ac08eeb)

This is an automated email from the ASF dual-hosted git repository.

paulk pushed a change to branch asf-site
in repository https://gitbox.apache.org/repos/asf/groovy-website.git.


    from a76a617  Reflect the aggregation status of .0 releases more accurately
     new a9e29e2  Reflect the aggregation status of .0 releases more accurately
     new ca2bf4d  Reflect the aggregation status of .0 releases more accurately
     new ac08eeb  bump asciidoctorj and groovy versions

The 3 revisions listed above as "new" are entirely new to this
repository and will be described in separate emails.  The revisions
listed as "add" were already present in the repository and have only
been added to this reference.


Summary of changes:
 generator/build.gradle                                     |  8 ++++----
 generator/src/main/groovy/generator/ChangelogParser.groovy |  6 +++---
 site/src/site/pages/changelogs.groovy                      | 14 ++++++--------
 3 files changed, 13 insertions(+), 15 deletions(-)


[groovy-website] 03/03: bump asciidoctorj and groovy versions

Posted by pa...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

paulk pushed a commit to branch asf-site
in repository https://gitbox.apache.org/repos/asf/groovy-website.git

commit ac08eeb90199270b277f3977e7044c3cb9806b40
Author: Paul King <pa...@asert.com.au>
AuthorDate: Mon May 20 18:45:22 2019 +1000

    bump asciidoctorj and groovy versions
---
 generator/build.gradle | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/generator/build.gradle b/generator/build.gradle
index dc55f00..b68660b 100644
--- a/generator/build.gradle
+++ b/generator/build.gradle
@@ -24,8 +24,8 @@ repositories {
 }
 
 dependencies {
-    ext.groovyVersion = '2.4.15'
-    ext.asciidocVersion = '1.5.8.1'
+    ext.groovyVersion = '2.4.17'
+    ext.asciidocVersion = '2.0.0'
     compile "org.codehaus.groovy:groovy:$groovyVersion"
     compile "org.codehaus.groovy:groovy-json:$groovyVersion"
     compile "org.codehaus.groovy:groovy-templates:$groovyVersion"
@@ -38,5 +38,5 @@ dependencies {
     //compile "org.jruby:jruby-complete:9.1.17.0"
 }
 
-compileGroovy.sourceCompatibility = '1.7'
-compileGroovy.targetCompatibility = '1.7'
+compileGroovy.sourceCompatibility = '1.8'
+compileGroovy.targetCompatibility = '1.8'


[groovy-website] 02/03: Reflect the aggregation status of .0 releases more accurately

Posted by pa...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

paulk pushed a commit to branch asf-site
in repository https://gitbox.apache.org/repos/asf/groovy-website.git

commit ca2bf4d37931bdff7a03ac35b1294e29f5d931f2
Author: Paul King <pa...@asert.com.au>
AuthorDate: Mon May 20 18:44:47 2019 +1000

    Reflect the aggregation status of .0 releases more accurately
---
 generator/src/main/groovy/generator/ChangelogParser.groovy | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/site/src/site/pages/changelogs.groovy b/site/src/site/pages/changelogs.groovy
index 450e0f3..7efd865 100644
--- a/site/src/site/pages/changelogs.groovy
+++ b/site/src/site/pages/changelogs.groovy
@@ -28,17 +28,15 @@ layout 'layouts/main.groovy', true,
                                 a(name: "changelog$mj") {}
                                 h2("Groovy $mj")
                                 ul {
-                                    minor.each { raw ->
-                                        def v = raw
+                                    minor.each { v ->
+                                        def ver = v
                                         def unreleased = ''
-                                        if (v.endsWith('-placeholder')) {
-                                            v -= '-placeholder'
-                                            unreleased = ' (unreleased)'
+                                        if (v.endsWith('-unreleased')) {
+                                            ver = (v - '-unreleased') + ' (unreleased)'
                                         }
                                         li {
-                                            yieldUnescaped ( !v.contains('-') && versions.any{ it.startsWith("$v-") } ? "Aggregate c" : "C" ) + "hangelog for "
-                                            a(href: "changelogs/changelog-${v}.html", "Groovy $v")
-                                            yieldUnescaped unreleased
+                                            yieldUnescaped ( v.endsWith('-unreleased') || (!v.contains('-') && versions.any{ it.startsWith("$v-") }) ? "Aggregate c" : "C" ) + "hangelog for "
+                                            a(href: "changelogs/changelog-${v}.html", "Groovy $ver")
                                         }
                                     }
                                 }
diff --git a/generator/src/main/groovy/generator/ChangelogParser.groovy b/generator/src/main/groovy/generator/ChangelogParser.groovy
index 72ddd42..70563e7 100644
--- a/generator/src/main/groovy/generator/ChangelogParser.groovy
+++ b/generator/src/main/groovy/generator/ChangelogParser.groovy
@@ -73,13 +73,13 @@ class ChangelogParser {
         def allMajor = changelogs.groupBy {
             def v = it.groovyVersion
             v.contains('-')?v-v.substring(v.indexOf('-')):v
-        }.findAll { ver, logs -> ver in releasedVersions || ver in ['2.6.0', '3.0.0'] }
+        }.findAll { ver, logs -> ver in releasedVersions || ver in ['2.6.0', '3.0.0'] } // 2.6, 3.0 added to get aggregate changelog
         allMajor.collect { k,v ->
             def changelog = changelogs.find { it.groovyVersion == k }
             if (!changelog) {
                 println "Not found: $k"
-                // it's useful to have an aggregate when we haven't done a '.0' release yet, use '-placeholder' to track
-                changelog = new Changelog(groovyVersion: k + '-placeholder', issues:[])
+                // it's useful to have an aggregate when we haven't done a '.0' release yet, use '-unreleased' to track
+                changelog = new Changelog(groovyVersion: k + '-unreleased', issues:[])
                 changelogs << changelog
             }
             v.each {


[groovy-website] 01/03: Reflect the aggregation status of .0 releases more accurately

Posted by pa...@apache.org.
This is an automated email from the ASF dual-hosted git repository.

paulk pushed a commit to branch asf-site
in repository https://gitbox.apache.org/repos/asf/groovy-website.git

commit a9e29e2d8c3a529415687c352904e3e612cf029c
Author: Paul King <pa...@asert.com.au>
AuthorDate: Mon May 20 18:44:21 2019 +1000

    Reflect the aggregation status of .0 releases more accurately
---
 site/src/site/pages/changelogs.groovy | 14 ++++++--------
 1 file changed, 6 insertions(+), 8 deletions(-)
